export class EngineMap {
    _mappings = new Map();
    set(name, extensions) {
        const engineName = name.trim().toLowerCase();
        const engineExtensions = new Array();
        if (extensions.length > 0 && name !== '') {
            // Clean engine extensions
            for (let extension of extensions) {
                extension = extension.trim().toLowerCase();
                if (!engineExtensions.includes(extension)) {
                    engineExtensions.push(extension);
                }
            }
            this._mappings.set(engineName, engineExtensions);
        }
    }
    delete(name) {
        this._mappings.delete(name.trim().toLowerCase());
    }
    deleteExtension(name, extension) {
        const engineName = name.trim().toLowerCase();
        const extensions = this._mappings.get(engineName);
        if (extensions) {
            const engineExtensions = new Array();
            for (const extension_ of extensions) {
                if (extension_ !== extension.trim().toLowerCase()) {
                    engineExtensions.push(extension_);
                }
            }
            this._mappings.set(engineName, engineExtensions);
        }
    }
    get(name) {
        return this._mappings.get(name.trim().toLowerCase());
    }
    getName(extension) {
        let engineName;
        for (const [name, extensions] of this._mappings) {
            if (extensions.includes(extension.trim().toLowerCase())) {
                engineName = name;
            }
        }
        return engineName;
    }
}
//# sourceMappingURL=engine-map.js.map