/* eslint-disable @typescript-eslint/no-unsafe-assignment, @typescript-eslint/no-unsafe-call, @typescript-eslint/no-unsafe-return, @typescript-eslint/no-unsafe-argument */
import fs from 'node:fs';
import * as _ from 'underscore';
import fumanchu from '@jaredwray/fumanchu';
import { BaseEngine } from '../base-engine.js';
export class Handlebars extends BaseEngine {
    partialsPath = ['partials', 'includes', 'templates'];
    constructor(options) {
        super();
        this.names = ['handlebars', 'mustache'];
        this.opts = options;
        this.engine = fumanchu;
        this.setExtensions(['hbs', 'hjs', 'handlebars', 'mustache']);
    }
    async render(source, data) {
        // Register partials
        if (this.rootTemplatePath) {
            this.initPartials();
        }
        const template = this.engine.compile(source, this.opts);
        let result = template(data, this.opts);
        result = _.unescape(result);
        return result;
    }
    renderSync(source, data) {
        // Register partials
        if (this.rootTemplatePath) {
            this.initPartials();
        }
        const template = this.engine.compile(source, this.opts);
        let result = template(data, this.opts);
        result = _.unescape(result);
        return result;
    }
    initPartials() {
        for (const path of this.partialsPath) {
            const fullPath = `${this.rootTemplatePath}/${path}`;
            this.registerPartials(fullPath);
        }
    }
    registerPartials(partialsPath) {
        let result = false;
        if (fs.existsSync(partialsPath)) {
            const partials = fs.readdirSync(partialsPath, { recursive: true, encoding: 'utf8' });
            for (const p of partials) {
                if (fs.statSync(partialsPath + '/' + p).isDirectory()) {
                    const directoryPartials = fs.readdirSync(partialsPath + '/' + p, { recursive: true, encoding: 'utf8' });
                    for (const dp of directoryPartials) {
                        const source = fs.readFileSync(partialsPath + '/' + p + '/' + dp).toString();
                        const name = p + '/' + dp.split('.')[0];
                        this.engine.registerPartial(name, this.engine.compile(source));
                    }
                }
                else {
                    const source = fs.readFileSync(partialsPath + '/' + p, 'utf8');
                    const name = p.split('.')[0];
                    this.engine.registerPartial(name, this.engine.compile(source));
                }
            }
            result = true;
        }
        return result;
    }
}
//# sourceMappingURL=handlebars.js.map